/*
 * Copyright (c) 2013 IBM Corporation.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 */
package classConstant;

class ClassConstant {

  public static void main(String args[]) {
    Class<ClassConstant> x = ClassConstant.class;
    x.hashCode();
  }

}
